@@ -2,7 +2,7 @@
 	common.c
 		includes most of the modules
 		this file is part of Cuhre
-		last modified 19 Dec 11 th
+		last modified 2 Aug 13 11 th
 */
 
 
@@ -11,13 +11,13 @@
 
 static inline bool BadDimension(cThis *t)
 {
-  if( t->ndim > NDIM ) return true;
+  if( t->ndim > MAXDIM ) return true;
   return t->ndim < 2;
 }
 
 static inline bool BadComponent(cThis *t)
 {
-  if( t->ncomp > NCOMP ) return true;
+  if( t->ncomp > MAXCOMP ) return true;
   return t->ncomp < 1;
 }
 
