@@ -2,7 +2,7 @@
 	Integrate.c
 		integrate over the unit hypercube
 		this file is part of Vegas
-		last modified 18 Apr 14 th
+		last modified 23 May 14 th
 */
 
 
@@ -51,8 +51,7 @@ static int Integrate(This *t, real *integral, real *error, real *prob)
   if( BadComponent(t) ) return -2;
   if( BadDimension(t) ) return -1;
 
-  InitWorker(t);
-  FrameAlloc(t, ShmRm(t));
+  FrameAlloc(t, Master);
   ForkCores(t);
   Alloc(bins, t->nbatch*t->ndim);
 
@@ -218,11 +217,9 @@ static int Integrate(This *t, real *integral, real *error, real *prob)
 abort:
   PutGrid(t, state_grid);
   free(bins);
-  WaitCores(t);
-  FrameFree(t);
+  FrameFree(t, Master);
 
   StateRemove(t);
-  ExitWorker(t);
 
   return fail;
 }
